/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.eventstream.internal;

import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.component.manager.ComponentLookupException;
import org.xwiki.component.manager.ComponentManager;
import org.xwiki.eventstream.EventStreamException;
import org.xwiki.eventstream.RecordableEventDescriptor;
import org.xwiki.eventstream.RecordableEventDescriptorManager;

/**
 * Default implementation of {@link org.xwiki.eventstream.RecordableEventDescriptorManager}.
 *
 * @version $Id: c92a00d9e8b5178faea8a3a2f15a515878d480d1 $
 * @since 9.2RC1
 */
@Component
@Singleton
public class DefaultRecordableEventDescriptorManager implements RecordableEventDescriptorManager
{
    @Inject
    private ComponentManager componentManager;

    @Override
    public List<RecordableEventDescriptor> getAllRecordableEventDescriptors() throws EventStreamException
    {
        try {
            return componentManager.getInstanceList(RecordableEventDescriptor.class);
        } catch (ComponentLookupException e) {
            throw new EventStreamException("Failed to retrieve the list of RecordableEventDescriptor.", e);
        }
    }
}
